#
# Copyright (c) 2021-2024 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
# LicenseRef-NvidiaProprietary
#
# NVIDIA CORPORATION, its affiliates and licensors retain all intellectual
# property and proprietary rights in and to this material, related
# documentation and any modifications thereto. Any use, reproduction,
# disclosure or distribution of this material and related documentation
# without an express license agreement from NVIDIA CORPORATION or
# its affiliates is strictly prohibited
#
from swsscommon import swsscommon

class NvosDBRender(object):
    MODEL = None    # Define in derived class

    def __init__(self):
        self._logger = None

    def process(self, logger):
        self._logger = logger
        db_sources = self.db_sources()
        data = {}
        for (db_name, table_name) in db_sources:
            self._logger.debug("Fetch data from table {}:{}".format(db_name, table_name))
            table = self.get_table(db_name, table_name)
            if data.get(db_name):
                data[db_name].update(table)
            else:
                data.update({db_name: table})
        # process retrieved data
        self.process_fullstate(data)

    def get_table(self, db_name, table_name):
        """Read an entire table from DB.
        Args:
            table_name: Table name.
        Returns:
            Table data in a dictionary form of
            { 'row_key': {'column_key': value, ...}, ...}
            or { ('l1_key', 'l2_key', ...): {'column_key': value, ...}, ...} for a multi-key table.
            Empty dictionary if table does not exist.
        """
        data = {}
        db = swsscommon.DBConnector(db_name, 0)
        table = swsscommon.Table(db, table_name)

        if table.get("")[0]:
            data[table_name] = dict(table.get("")[1])
        else:
            for key in table.getKeys():
                temp = dict(table.get(key)[1])
                new_dict = {key: temp}
                if data.get(table_name):
                    data[table_name].update(new_dict)
                else:
                    data.update({table_name: new_dict})

        return data
    def handle_periodic_timeout(self):
        raise NotImplementedError

    def db_sources(self):
        raise NotImplementedError

    def process_fullstate(self, data):
        raise NotImplementedError

    def data_get(self, data, db_name, table_name):
        return data.get(db_name, {}).get(table_name, {})

    def default_callback(self):
        pass

